Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: extensions/browser/api/web_request/web_request_api_helpers.h

Issue 1853283002: Map webRequest filter type to multiple internal ResourceTypes if needed (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: extensions/browser/api/web_request/web_request_api_helpers.h
diff --git a/extensions/browser/api/web_request/web_request_api_helpers.h b/extensions/browser/api/web_request/web_request_api_helpers.h
index a867fee07d3f31d986d1247aa10a970f7bb8dddb..a41c52ff48493171334067a1c98d8ef2d4d78944 100644
--- a/extensions/browser/api/web_request/web_request_api_helpers.h
+++ b/extensions/browser/api/web_request/web_request_api_helpers.h
@@ -349,11 +349,11 @@ bool IsRelevantResourceType(content::ResourceType type);
// by the web request API.
const char* ResourceTypeToString(content::ResourceType type);
// Stores a |content::ResourceType| representation in |type| if |type_str| is
// a resource type handled by the web request API. Returns true in case of
// success.
bool ParseResourceType(const std::string& type_str,
- content::ResourceType* type);
+ std::vector<content::ResourceType>* types);
} // namespace extension_web_request_api_helpers
« no previous file with comments | « extensions/browser/api/web_request/web_request_api.cc ('k') | extensions/browser/api/web_request/web_request_api_helpers.cc » ('j') | no next file with comments »
@@ -349,11 +349,11 @@ bool IsRelevantResourceType(content::ResourceType type);
// by the web request API.
const char* ResourceTypeToString(content::ResourceType type);
-// Stores a |content::ResourceType| representation in |type| if |type_str| is
+// Stores a |content::ResourceType| representation in |types| if |type_str| is
// a resource type handled by the web request API. Returns true in case of
// success.

Powered by Google App Engine
This is Rietveld 408576698